@@ -2014,3 +2014,9 @@ class VariableClBuilderWithBdepsOptSet(Variable):
 
     def get(self):
         return self.Get('cl_builder_with_bdeps_set')
+
+class VariableClBuilderBootParams(Variable):
+    """
+    Параметры загрузки ядра в собираемом образе и boot live
+    """
+    value = ""
