@@ -91,7 +91,8 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     update.VariableClUpdateRepUrl(section="update"),
                     update.VariableClUpdateRep(section="update"),
                     update.VariableClUpdateRepRev(section="update"),
-                    update.VariableClUpdateBranch(section="update"),
+                    update.VariableClUpdateBranch(section="update",
+                        arch_var="os_profile_arch_machine"),
                     update.VariableClUpdateBranchName(section="update"),
                     update.VariableClProfileRepository(section="update"),
                     update.VariableClUpdateBinhost(section="update"),
@@ -112,6 +113,7 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                         section="update"),
                     update.VariableClUpdateBinhostRevisionPath(
                         section="update"),
+                    VariableOsProfileArchMachine(systemRoot=self.systemRoot),
                     system.VariableOsArchMachineGentoo()]
 
     @classmethod
@@ -279,6 +281,16 @@ class VariableOsBuilderArchMachine(BuilderLinux):
         return ""
 
 
+class VariableOsProfileArchMachine(ReadonlyVariable):
+    systemRoot = "/"
+
+    def get(self):
+        if path.exists(path.join(self.systemRoot, 'lib64')):
+            return 'x86_64'
+        else:
+            return 'i686'
+
+
 class VariableOsBuilderLinuxFiles(BuilderLinux):
     """Shortname of system"""
     variable = "os_linux_files"
